@@ -8,8 +8,9 @@ import time
 import datetime
 import gzip
 import glob
-from PIL import Image, ExifTags
-from PIL.ExifTags import TAGS
+
+import Image, ExifTags
+from ExifTags import TAGS
 
 from optparse import make_option
 from django.core.management.base import BaseCommand, CommandError
@@ -134,7 +135,7 @@ class Command(BaseCommand):
         total = 0
         size = 1000, 1000
 
-        folder_metadata = c.metadata('/Web/')
+        folder_metadata = c.metadata('/')
         #print "*"*80
         #print "metadata:", folder_metadata
         #print "*"*80
