@@ -154,7 +154,7 @@ class Command(BaseCommand):
         total = 0
         size = 1000, 1000
 
-        folder_metadata = c.metadata('/Web/')
+        folder_metadata = c.metadata('/')
         #print "*"*80
         #print "metadata:", folder_metadata
         #print "*"*80
